@@ -1,3 +1,3 @@
-bnplot <- function(dag, shape = "circle", main = NULL, sub = NULL) {
+bnplot <- function(dag, shape = "ellipse", main = NULL, sub = NULL) {
   bnlearn::graphviz.plot(x = dag, shape = shape, main = main, sub = sub)
 }
